[Groonga-commit] groonga/groonga-command at d0bdad7 [master] Really change conf* -> config*

Back to archive index

Kouhei Sutou null+****@clear*****
Tue Jan 19 23:54:30 JST 2016


Kouhei Sutou	2016-01-19 23:54:30 +0900 (Tue, 19 Jan 2016)

  New Revision: d0bdad797eff770afbdbdb176748def59e9c718a
  https://github.com/groonga/groonga-command/commit/d0bdad797eff770afbdbdb176748def59e9c718a

  Message:
    Really change conf* -> config*

  Modified files:
    lib/groonga/command/config-delete.rb
    lib/groonga/command/config-get.rb
    lib/groonga/command/config-set.rb
    lib/groonga/command/dump.rb
    test/command/test-dump.rb
  Renamed files:
    test/command/test-config-delete.rb
      (from test/command/test-conf-delete.rb)
    test/command/test-config-get.rb
      (from test/command/test-conf-get.rb)
    test/command/test-config-set.rb
      (from test/command/test-conf-set.rb)

  Modified: lib/groonga/command/config-delete.rb (+4 -4)
===================================================================
--- lib/groonga/command/dump.rb    2016-01-16 19:11:15 +0900 (913d2d3)
+++ lib/groonga/command/dump.rb    2016-01-19 23:54:30 +0900 (80c8369)
@@ -31,7 +31,7 @@ module Groonga
             :dump_schema,
             :dump_records,
             :dump_indexes,
-            :dump_confs,
+            :dump_configs,
           ]
         end
       end

  Renamed: test/command/test-config-delete.rb (+5 -5) 82%
===================================================================
--- test/command/test-conf-delete.rb    2016-01-16 19:11:15 +0900 (2f786a3)
+++ test/command/test-config-delete.rb    2016-01-19 23:54:30 +0900 (ebc03f1)
@@ -16,17 +16,17 @@
 
 class ConfigDeleteCommandTest < Test::Unit::TestCase
   private
-  def conf_delete_command(pair_arguments={}, ordered_arguments=[])
+  def config_delete_command(pair_arguments={}, ordered_arguments=[])
     Groonga::Command::ConfigDelete.new("config_delete",
-                                     pair_arguments,
-                                     ordered_arguments)
+                                       pair_arguments,
+                                       ordered_arguments)
   end
 
   class ConstructorTest < self
     def test_ordered_arguments
       key = "alias.table"
 
-      command = conf_delete_command({},
+      command = config_delete_command({},
                                     [
                                       key,
                                     ])
@@ -39,7 +39,7 @@ class ConfigDeleteCommandTest < Test::Unit::TestCase
 
   class KeyTest < self
     def test_reader
-      command = conf_delete_command(:key => "alias.table")
+      command = config_delete_command(:key => "alias.table")
       assert_equal("alias.table", command.key)
     end
   end

  Renamed: test/command/test-config-get.rb (+6 -6) 82%
===================================================================
--- test/command/test-conf-get.rb    2016-01-16 19:11:15 +0900 (1910bfb)
+++ test/command/test-config-get.rb    2016-01-19 23:54:30 +0900 (7fc54ae)
@@ -16,7 +16,7 @@
 
 class ConfigGetCommandTest < Test::Unit::TestCase
   private
-  def conf_get_command(pair_arguments={}, ordered_arguments=[])
+  def config_get_command(pair_arguments={}, ordered_arguments=[])
     Groonga::Command::ConfigGet.new("config_get",
                                   pair_arguments,
                                   ordered_arguments)
@@ -26,10 +26,10 @@ class ConfigGetCommandTest < Test::Unit::TestCase
     def test_ordered_arguments
       key = "alias.table"
 
-      command = conf_get_command({},
-                                 [
-                                   key,
-                                 ])
+      command = config_get_command({},
+                                   [
+                                     key,
+                                   ])
       assert_equal({
                      :key => key,
                    },
@@ -39,7 +39,7 @@ class ConfigGetCommandTest < Test::Unit::TestCase
 
   class KeyTest < self
     def test_reader
-      command = conf_get_command(:key => "alias.table")
+      command = config_get_command(:key => "alias.table")
       assert_equal("alias.table", command.key)
     end
   end

  Renamed: test/command/test-config-set.rb (+9 -9) 77%
===================================================================
--- test/command/test-conf-set.rb    2016-01-16 19:11:15 +0900 (0cd1b8c)
+++ test/command/test-config-set.rb    2016-01-19 23:54:30 +0900 (7f0feb3)
@@ -16,7 +16,7 @@
 
 class ConfigSetCommandTest < Test::Unit::TestCase
   private
-  def conf_set_command(pair_arguments={}, ordered_arguments=[])
+  def config_set_command(pair_arguments={}, ordered_arguments=[])
     Groonga::Command::ConfigSet.new("config_set",
                                   pair_arguments,
                                   ordered_arguments)
@@ -27,11 +27,11 @@ class ConfigSetCommandTest < Test::Unit::TestCase
       key   = "alias.table"
       value = "Aliases"
 
-      command = conf_set_command({},
-                                 [
-                                   key,
-                                   value,
-                                 ])
+      command = config_set_command({},
+                                   [
+                                     key,
+                                     value,
+                                   ])
       assert_equal({
                      :key   => key,
                      :value => value,
@@ -42,15 +42,15 @@ class ConfigSetCommandTest < Test::Unit::TestCase
 
   class KeyTest < self
     def test_reader
-      command = conf_set_command(:key => "alias.table")
+      command = config_set_command(:key => "alias.table")
       assert_equal("alias.table", command.key)
     end
   end
 
   class ValueTest < self
     def test_reader
-      command = conf_set_command(:key => "alias.table",
-                                 :value => "Aliases")
+      command = config_set_command(:key => "alias.table",
+                                   :value => "Aliases")
       assert_equal("Aliases", command.value)
     end
   end

  Modified: test/command/test-dump.rb (+3 -3)
===================================================================
--- test/command/test-dump.rb    2016-01-16 19:11:15 +0900 (36e0e6f)
+++ test/command/test-dump.rb    2016-01-19 23:54:30 +0900 (1e97e19)
@@ -29,7 +29,7 @@ class DumpCommandTest < Test::Unit::TestCase
       dump_schema  = "yes"
       dump_records = "no"
       dump_indexes = "yes"
-      dump_confs   = "no"
+      dump_configs = "no"
 
       command = dump_command({},
                              [
@@ -38,7 +38,7 @@ class DumpCommandTest < Test::Unit::TestCase
                                dump_schema,
                                dump_records,
                                dump_indexes,
-                               dump_confs,
+                               dump_configs,
                              ])
       assert_equal({
                      :tables       => tables,
@@ -46,7 +46,7 @@ class DumpCommandTest < Test::Unit::TestCase
                      :dump_schema  => dump_schema,
                      :dump_records => dump_records,
                      :dump_indexes => dump_indexes,
-                     :dump_confs   => dump_confs,
+                     :dump_configs => dump_configs,
                    },
                    command.arguments)
     end
-------------- next part --------------
HTML����������������������������...
Télécharger 



More information about the Groonga-commit mailing list
Back to archive index
--- lib/groonga/command/config-delete.rb    2016-01-16 19:11:15 +0900 (ad54c82)
+++ lib/groonga/command/config-delete.rb    2016-01-19 23:54:30 +0900 (1b4b461)
@@ -18,11 +18,11 @@ require "groonga/command/base"
 
 module Groonga
   module Command
     # A command class that represents `conf_delete` command.
     #
-    # @since 1.1.4
-    class ConfDelete < Base
-      Command.register("conf_delete", self)
+    # @since 1.1.5
+    class ConfigDelete < Base
+      Command.register("config_delete", self)
 
       class << self
         def parameter_names
@@ -18,11 +18,11 @@ require "groonga/command/base"
 module Groonga
   module Command
-    # A command class that represents `conf_delete` command.
+    # A command class that represents `config_delete` command.
     #

  Modified: lib/groonga/command/config-get.rb (+4 -4)
===================================================================
--- lib/groonga/command/config-get.rb    2016-01-16 19:11:15 +0900 (d12b900)
+++ lib/groonga/command/config-get.rb    2016-01-19 23:54:30 +0900 (48b8403)
@@ -18,11 +18,11 @@ require "groonga/command/base"
 
 module Groonga
   module Command
     # A command class that represents `conf_get` command.
     #
-    # @since 1.1.4
-    class ConfGet < Base
-      Command.register("conf_get", self)
+    # @since 1.1.5
+    class ConfigGet < Base
+      Command.register("config_get", self)
 
       class << self
         def parameter_names
@@ -18,11 +18,11 @@ require "groonga/command/base"
 module Groonga
   module Command
-    # A command class that represents `conf_get` command.
+    # A command class that represents `config_get` command.
     #

  Modified: lib/groonga/command/config-set.rb (+4 -4)
===================================================================
--- lib/groonga/command/config-set.rb    2016-01-16 19:11:15 +0900 (2341660)
+++ lib/groonga/command/config-set.rb    2016-01-19 23:54:30 +0900 (8ce136e)
@@ -18,11 +18,11 @@ require "groonga/command/base"
 
 module Groonga
   module Command
     # A command class that represents `conf_set` command.
     #
-    # @since 1.1.4
-    class ConfSet < Base
-      Command.register("conf_set", self)
+    # @since 1.1.5
+    class ConfigSet < Base
+      Command.register("config_set", self)
 
       class << self
         def parameter_names
@@ -18,11 +18,11 @@ require "groonga/command/base"
 module Groonga
   module Command
-    # A command class that represents `conf_set` command.
+    # A command class that represents `config_set` command.
     #

  Modified: lib/groonga/command/dump.rb (+1 -1)
===================================================================